@@ -8,7 +8,7 @@ from .settings import PelicanMathSettings
 def init_math(sender: Pelican):
     settings = PelicanMathSettings.from_settings(sender)
     sender.settings["MARKDOWN"].setdefault("extensions", []).append(
-        PelicanMathExtension(settings)
+        PelicanMathExtension(settings),
     )
 
 
